@@ -1,4 +1,5 @@
 #!/bin/false
+# ABSTRACT: MAC address functions and object
 
 package NetAddr::MAC;
 use strict;
@@ -38,7 +39,7 @@ use constant ETHER2TOKEN => (
 
 use base qw( Exporter );
 use vars qw( $VERSION %EXPORT_TAGS @EXPORT_OK );
-$VERSION = (qw$Revision: 0.82 $)[1];
+$VERSION = (qw$Revision: 0.83 $)[1];
 
 %EXPORT_TAGS = (
     all => [
@@ -73,6 +74,7 @@ $VERSION = (qw$Revision: 0.82 $)[1];
 
 Exporter::export_ok_tags( keys %EXPORT_TAGS );
 
+=encoding utf8
 =head1 NAME
 
 NetAddr::MAC - Handles hardware MAC Addresses (EUI-48 and EUI-64)
@@ -129,17 +131,18 @@ NetAddr::MAC - Handles hardware MAC Addresses (EUI-48 and EUI-64)
     print 'Sun Format: ',  mac_as_sun($mac),"\n";
     print 'Token Ring Format: ',mac_as_tokenring($mac),"\n";
 
-
 =head1 DESCRIPTION
 
 This module provides an interface to deal with Media Access Control (or MAC)
-addresses.  These are the addresses that uniquely identify a device on a
-layer 2 network.  Although the common case is hardware addresses on Ethernet
-network cards, there are a variety of devices that use this system.
+addresses.  These are the addresses that uniquely identify a device on
+various layer 2 networks. Although the most common case is hardware addresses
+on Ethernet network cards, there are a variety of devices that use this
+system of addressing.
+
 This module supports both EUI-48 and EUI-64 addresses and implements an
 OO and a functional interface.
 
-Some devices that use EUI-48 (or MAC-48) addresses include:
+Some networks that use EUI-48 (or MAC-48) addresses include:
 
     Ethernet
     802.11 wireless networks
@@ -148,34 +151,12 @@ Some devices that use EUI-48 (or MAC-48) addresses include:
     FDDI
     ATM
 
-Some devices that use EUI-64 addresses include:
+Some networks that use EUI-64 addresses include:
 
     Firewire
-    IPv6
+    IPv6 (sort of)
     ZigBee / 802.15.4 wireless personal-area networks
 
-=head1 MOTIVATION
-
-We have lots of systems at my work which handle MAC addresses. There was lots
-of code validating and normalising them all over the place. So I set about
-creating a reusable module to add to our SOE install so that MAC address
-handling becomes both powerful and trivial at the same time.
-
-There are several other MAC address modules on CPAN. I didn't like one of them
-and the one, I did like, but it dragged Moose in. So I created this module,
-taking the ideas I liked from the other two modules and adding in extra bits
-that I needed (and a few features just for completeness) whilst avoiding
-dependancies and avoiding anything that doesnt work on perl 5.6
-
-I hope that the result is useful to others, the concept is to be able to create
-an object representing a MAC address based on a string that only very vaguely
-resembles a MAC address. From there, to be able to output normalised string
-representations of the mac address in a variety of common formats.
-
-A templating function is deliberately omitted, as very niche outputs can easily
-be derived from the 'basic' format.
-
-Feel free to send patches for features you add.
 
 =head1 OO METHODS
 
@@ -191,7 +172,11 @@ As above, but %options may include any or none of the following
 
 =item * die_on_error
 
-If set to true, errors will result in a die (croak) rather than populating $errstr
+If set to true, errors will result in a die (croak) rather than populating I<$errstr>
+
+B<Take care when using the mac_is_* functions!> they will return false in both
+the case of an error and according to the properties of the MAC address. You will
+therefore need to enable die_on_error or check I<$errstr> when false is returned.
 
 =back
 
@@ -211,6 +196,9 @@ sub new {
     my $c = ref($p) || $p;
     my $self = bless {}, $c;
 
+	# clear the errstr, see also RT96045
+	$NetAddr::MAC::errstr = undef;
+
     unless (@a) {
         my $e = q|Please provide a mac address|;
         croak "$e\n" if $NetAddr::MAC::die_on_error;
@@ -363,7 +351,16 @@ sub original {
 
 =head2 errstr
 
-returns the error (if one occured)
+returns the error (if one occured).
+
+This is intended for use with the object. Its not exported at all.
+
+Note: this method is used once the NetAddr::MAC object is successfully
+created. For now the to_eui48 method is the only method that will
+return an error once the object is created.
+
+When creating objects, you will need to catch errors with either the
+I<or> function, or the I<eval> way.
 
 =cut
 
@@ -613,6 +610,9 @@ sub as_tokenring {
 
 converts to EUI-48 (if the eui-64 was derived from eui-48)
 
+this function will fail if the mac was not derived from eui-48.
+you will need to catch it and inspect the error message.
+
 =cut
 
 sub to_eui48 {
@@ -632,8 +632,8 @@ sub to_eui48 {
         else {
             my $e = 'eui-64 address is not derived from an eui-48 address';
             croak "$e\n" if $self->{_die};
-            $NetAddr::MAC::errstr = $e;
-            return;
+  		    $self->{_errstr} = $e;
+  		    return
         }
     }
 
@@ -655,8 +655,10 @@ sub to_eui64 {
 
         # convert to eui-64
         $self->{mac} = [
-            @{ $self->{mac} }[ 0 .. 2 ], 0xff,
-            0xfe,                        @{ $self->{mac} }[ 3 .. 5 ]
+            @{ $self->{mac} }[ 0 .. 2 ],
+            0xff,
+            0xfe,
+            @{ $self->{mac} }[ 3 .. 5 ]
         ];
 
     }
@@ -1044,18 +1046,18 @@ sub mac_as_tokenring {
 
 =head1 ERROR HANDLING
 
-Prior to 0.8 every error resulted in a die (croak) which need to be caught.
+Prior to 0.8 every error resulted in a die (croak) which needed to be caught.
 As I have used this module more, having to catch them all the time is tiresome.
-So from 0.8 onwards, errors result in an undef and something being set.
+So from 0.8 onwards, errors result in an I<undef> and something being set.
 
-For objects, this something is accessible via B<<$self->errstr>> otherwise
+For objects, this something is accessible via B<$self-E<gt>errstr> otherwise
 ther error is in B<$NetAddr::MAC::errstr>;
 
 If you would like to have die (croak) instead, you can either set the global
 B<$NetAddr::MAC::die_on_error> or set the B<die_on_error> option when creating
 an object. When creating objects, the provided option takes priority over the
 global. So if you set the global, then all objects will die - unless you
-specifcy otherwise.
+specify otherwise.
 
 =head2 Global examples
 
@@ -1116,6 +1118,10 @@ Or do it globally
 
   }
 
+=head1 VERSION
+
+ 0.82
+
 =head1 CREDITS
 
 Stolen lots of ideas and some pod content from L<Device::MAC> and L<Net::MAC>
@@ -1143,6 +1149,34 @@ Dean Hamstead C<< <dean@bytefoundry.com.au> >>
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 MOTIVATION
+
+There are lots of systems at my (then) place of work which handle MAC
+addresses. There was lots of code validating and normalising them all over
+the place - most of it was quirky and sloppy. So I set about creating a
+reusable module to add to our SOE install so that MAC address handling
+would become consistent, reliable, powerful and trivial.
+
+Generally speaking this module fulfills that goal. It's very convenient
+to be able to use MAC addresses in any format throughout those systems.
+
+There are several other MAC address modules on CPAN. I didn't like the
+interface on one, the other dragged in Moose. So I created this module,
+taking the ideas I liked from the other two modules and adding in extra bits
+that I needed (and a few features just for completeness) whilst avoiding
+dependancies and avoiding anything that doesnt work on perl 5.6
+
+I hope that the result is useful to others, the concept is to be able to create
+an object representing a MAC address based on a string that only very vaguely
+resembles a MAC address. From there, to be able to output normalised string
+representations of the mac address in a variety of common formats.
+
+A templating function is deliberately omitted, as very niche outputs can easily
+be derived from the 'basic' format.
+
+Feel free to send patches for features you add, I appreciate those who
+have done so far and endeavour to incoporate new patches ASAP.
+
 =cut
 
 1;
